@@ -53,12 +53,18 @@ FAILEDOPERATION_CREATEAUDITFAILERROR = 'FailedOperation.CreateAuditFailError'
 # Failed to assign an exclusive VIP to the read-only replica.
 FAILEDOPERATION_CREATEROVIPERROR = 'FailedOperation.CreateRoVipError'
 
+# Database operation failed.
+FAILEDOPERATION_DBOPERATIONACTIONERROR = 'FailedOperation.DBOperationActionError'
+
 # Failed to query database proxy.
 FAILEDOPERATION_DESCRIBEPROXYGROUPERROR = 'FailedOperation.DescribeProxyGroupError'
 
 # An error occurred while obtaining permissions.
 FAILEDOPERATION_GETPRIVILEGEERROR = 'FailedOperation.GetPrivilegeError'
 
+# Query failed.
+FAILEDOPERATION_INSTANCEQUERYERROR = 'FailedOperation.InstanceQueryError'
+
 # Failed to deserialize JSON.
 FAILEDOPERATION_JSONUNMARSHALERROR = 'FailedOperation.JsonUnmarshalError'
 
@@ -143,7 +149,10 @@ INTERNALERROR_DFWERROR = 'InternalError.DfwError'
 # SQL statement error
 INTERNALERROR_EXESQLERROR = 'InternalError.ExeSqlError'
 
-# 
+# Failed to execute the HTTP request
+INTERNALERROR_EXECHTTPREQUESTERROR = 'InternalError.ExecHttpRequestError'
+
+# Failed to execute SQL statement
 INTERNALERROR_EXECUTESQLERROR = 'InternalError.ExecuteSQLError'
 
 # File transfer exception
@@ -230,6 +239,9 @@ INVALIDPARAMETER = 'InvalidParameter'
 # This API was not found.
 INVALIDPARAMETER_CONTROLLERNOTFOUNDERROR = 'InvalidParameter.ControllerNotFoundError'
 
+# There are resources in the placement group.
+INVALIDPARAMETER_DEPLOYGROUPNOTEMPTY = 'InvalidParameter.DeployGroupNotEmpty'
+
 # Parameter exception.
 INVALIDPARAMETER_EXCEPTIONPARAM = 'InvalidParameter.ExceptionParam'
 
@@ -251,6 +263,9 @@ INVALIDPARAMETER_INVALIDPARAMETERERROR = 'InvalidParameter.InvalidParameterError
 # Failed to deserialize JSON.
 INVALIDPARAMETER_JSONUNMARSHALERROR = 'InvalidParameter.JsonUnmarshalError'
 
+# The quota of placement group resources has been exceeded.
+INVALIDPARAMETER_OVERDEPLOYGROUPQUOTA = 'InvalidParameter.OverDeployGroupQuota'
+
 # The resource already exists.
 INVALIDPARAMETER_RESOURCEEXISTS = 'InvalidParameter.ResourceExists'
 
@@ -359,7 +374,7 @@ OPERATIONDENIED_DELETEROOTACCOUNTERROR = 'OperationDenied.DeleteRootAccountError
 # This instance needs permissions to use this feature.
 OPERATIONDENIED_FUNCTIONDENIED = 'OperationDenied.FunctionDenied'
 
-# 
+# The current instance type does not support this operation.
 OPERATIONDENIED_INSTTYPENOTSUPPORT = 'OperationDenied.InstTypeNotSupport'
 
 # Instance locks are in conflict. Please try again later.
