@@ -32,6 +32,9 @@ FAILEDOPERATION_INVALIDUSER = 'FailedOperation.InvalidUser'
 # Internal error.
 INTERNALERROR = 'InternalError'
 
+# Data error.
+INTERNALERROR_ACCESSDBERROR = 'InternalError.AccessDBError'
+
 # Internal error: failed to generate template ID.
 INTERNALERROR_GENDEFINITION = 'InternalError.GenDefinition'
 
