@@ -26,19 +26,19 @@ AUTHFAILURE = 'AuthFailure'
 # The ENI information is not available in this address.
 FAILEDOPERATION_ADDRESSENIINFONOTFOUND = 'FailedOperation.AddressEniInfoNotFound'
 
-# 
+# Insufficient account balance.
 FAILEDOPERATION_BALANCEINSUFFICIENT = 'FailedOperation.BalanceInsufficient'
 
 # Unsupported region.
 FAILEDOPERATION_INVALIDREGION = 'FailedOperation.InvalidRegion'
 
-# 
+# The instance's primary ENI is not found.
 FAILEDOPERATION_MASTERENINOTFOUND = 'FailedOperation.MasterEniNotFound'
 
 # Network probe timed out. Please retry later.
 FAILEDOPERATION_NETDETECTTIMEOUT = 'FailedOperation.NetDetectTimeOut'
 
-# 
+# Task execution failed.
 FAILEDOPERATION_TASKFAILED = 'FailedOperation.TaskFailed'
 
 # An internal error occurred.
@@ -47,6 +47,9 @@ INTERNALERROR = 'InternalError'
 # Failed to create the Ckafka route. Please retry later.
 INTERNALERROR_CREATECKAFKAROUTEERROR = 'InternalError.CreateCkafkaRouteError'
 
+# 
+INTERNALERROR_MODULEERROR = 'InternalError.ModuleError'
+
 # Internal error.
 INTERNALSERVERERROR = 'InternalServerError'
 
@@ -176,6 +179,9 @@ INVALIDPARAMETERVALUE_INCONSISTENTINSTANCEINTERNETCHARGETYPE = 'InvalidParameter
 # This instance does not support an Anycast EIP.
 INVALIDPARAMETERVALUE_INSTANCEDOESNOTSUPPORTANYCAST = 'InvalidParameterValue.InstanceDoesNotSupportAnycast'
 
+# 
+INVALIDPARAMETERVALUE_INSTANCEHASNOWANIP = 'InvalidParameterValue.InstanceHasNoWanIP'
+
 # This instance already has a WanIP (public IP).
 INVALIDPARAMETERVALUE_INSTANCEHASWANIP = 'InvalidParameterValue.InstanceHasWanIP'
 
@@ -278,6 +284,9 @@ INVALIDPARAMETERVALUE_RESOURCENOTSUPPORT = 'InvalidParameterValue.ResourceNotSup
 # Subnet CIDR conflict.
 INVALIDPARAMETERVALUE_SUBNETCONFLICT = 'InvalidParameterValue.SubnetConflict'
 
+# The CIDR block overlaps with another subnet within the same VPC.
+INVALIDPARAMETERVALUE_SUBNETOVERLAP = 'InvalidParameterValue.SubnetOverlap'
+
 # The subnet IP range overlaps with the secondary CIDR block.
 INVALIDPARAMETERVALUE_SUBNETOVERLAPASSISTCIDR = 'InvalidParameterValue.SubnetOverlapAssistCidr'
 
@@ -446,10 +455,10 @@ LIMITEXCEEDED_TAGTAGSEXCEEDED = 'LimitExceeded.TagTagsExceeded'
 # Missing parameter.
 MISSINGPARAMETER = 'MissingParameter'
 
-# 
+# The specified public IP is isolated.
 OPERATIONDENIED_ADDRESSINARREARS = 'OperationDenied.AddressInArrears'
 
-# 
+# Mutually exclusive tasks are executing.
 OPERATIONDENIED_MUTEXTASKRUNNING = 'OperationDenied.MutexTaskRunning'
 
 # The resource is occupied.
@@ -479,7 +488,7 @@ RESOURCEUNAVAILABLE_SERVICEWHITELISTNOTADDED = 'ResourceUnavailable.ServiceWhite
 # Unauthorized operation.
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
-# 
+# No permission to apply for AnycastEip resources.
 UNAUTHORIZEDOPERATION_ANYCASTEIP = 'UnauthorizedOperation.AnycastEip'
 
 # The binding relationship does not exist.
@@ -560,6 +569,9 @@ UNSUPPORTEDOPERATION_CLBPOLICYLIMIT = 'UnsupportedOperation.ClbPolicyLimit'
 # The IP range overlaps with that of the TKE container under the VPC.
 UNSUPPORTEDOPERATION_CONFLICTWITHDOCKERROUTE = 'UnsupportedOperation.ConflictWithDockerRoute'
 
+# Unable to delete: There’re NAT rules associated with this direct connect gateway. Please delete all NAT rules first. 
+UNSUPPORTEDOPERATION_DCGATEWAYNATRULEEXISTS = 'UnsupportedOperation.DCGatewayNatRuleExists'
+
 # No direct connect gateway exists in the specified VPC.
 UNSUPPORTEDOPERATION_DCGATEWAYSNOTFOUNDINVPC = 'UnsupportedOperation.DcGatewaysNotFoundInVpc'
 
@@ -602,6 +614,9 @@ UNSUPPORTEDOPERATION_INCORRECTADDRESSRESOURCETYPE = 'UnsupportedOperation.Incorr
 # The configured instance does not match with the route table.
 UNSUPPORTEDOPERATION_INSTANCEANDRTBNOTMATCH = 'UnsupportedOperation.InstanceAndRtbNotMatch'
 
+# The specified instance resource does not match.
+UNSUPPORTEDOPERATION_INSTANCEMISMATCH = 'UnsupportedOperation.InstanceMismatch'
+
 # In cross-account association, instances under an ordinary account cannot be associated with CCNs created under an Auto-Driving Cloud account.
 UNSUPPORTEDOPERATION_INSTANCEORDINARYACCOUNTREFUSEATTACH = 'UnsupportedOperation.InstanceOrdinaryAccountRefuseAttach'
 
@@ -644,7 +659,7 @@ UNSUPPORTEDOPERATION_ISPNOTSUPPORTED = 'UnsupportedOperation.IspNotSupported'
 # The specified CDC instance already has a local gateway.
 UNSUPPORTEDOPERATION_LOCALGATEWAYALREADYEXISTS = 'UnsupportedOperation.LocalGatewayAlreadyExists'
 
-# 
+# The account does not support modifying this attribute of the public IP.
 UNSUPPORTEDOPERATION_MODIFYADDRESSATTRIBUTE = 'UnsupportedOperation.ModifyAddressAttribute'
 
 # The resource mutual exclusion operation is being executed.
@@ -653,6 +668,9 @@ UNSUPPORTEDOPERATION_MUTEXOPERATIONTASKRUNNING = 'UnsupportedOperation.MutexOper
 # The private IP specified in the SNAT/DNAT forwarding rule has been bound with another rule.
 UNSUPPORTEDOPERATION_NATGATEWAYRULEPIPEXISTS = 'UnsupportedOperation.NatGatewayRulePipExists'
 
+# 
+UNSUPPORTEDOPERATION_NATGATEWAYSNATPIPNEEDVM = 'UnsupportedOperation.NatGatewaySnatPipNeedVm'
+
 # The specified NAT Gateway type does not support configuring a SNAT rule.
 UNSUPPORTEDOPERATION_NATGATEWAYTYPENOTSUPPORTSNAT = 'UnsupportedOperation.NatGatewayTypeNotSupportSNAT'
 
@@ -680,7 +698,7 @@ UNSUPPORTEDOPERATION_NOTSUPPORTEDUPDATECCNROUTEPUBLISH = 'UnsupportedOperation.N
 # The specified routing policy cannot be published to or withdrawn from CCN.
 UNSUPPORTEDOPERATION_NOTIFYCCN = 'UnsupportedOperation.NotifyCcn'
 
-# 
+# This billing mode is disused. Please try another billing mode.
 UNSUPPORTEDOPERATION_OFFLINECHARGETYPE = 'UnsupportedOperation.OfflineChargeType'
 
 # Only the Ckafka Pro Edition is supported.
@@ -707,12 +725,21 @@ UNSUPPORTEDOPERATION_PUBLICIPADDRESSNOTBILLEDBYTRAFFIC = 'UnsupportedOperation.P
 # The current account can not use this service in the current region.
 UNSUPPORTEDOPERATION_PURCHASELIMIT = 'UnsupportedOperation.PurchaseLimit'
 
+# This record already exists.
+UNSUPPORTEDOPERATION_RECORDEXISTS = 'UnsupportedOperation.RecordExists'
+
+# The record does not exist.
+UNSUPPORTEDOPERATION_RECORDNOTEXISTS = 'UnsupportedOperation.RecordNotExists'
+
 # The resource ID entered does not match with any resource bound with the IP. Check and try again.
 UNSUPPORTEDOPERATION_RESOURCEMISMATCH = 'UnsupportedOperation.ResourceMismatch'
 
-# 
+# No roles available. Please confirm whether you get the authorization for the role.
 UNSUPPORTEDOPERATION_ROLENOTFOUND = 'UnsupportedOperation.RoleNotFound'
 
+# The routing table is bound to a subnet.
+UNSUPPORTEDOPERATION_ROUTETABLEHASSUBNETRULE = 'UnsupportedOperation.RouteTableHasSubnetRule'
+
 # The endpoint created by the specified endpoint service cannot be bound to a security group.
 UNSUPPORTEDOPERATION_SPECIALENDPOINTSERVICE = 'UnsupportedOperation.SpecialEndPointService'
 
@@ -752,6 +779,9 @@ UNSUPPORTEDOPERATION_UNBINDEIP = 'UnsupportedOperation.UnbindEIP'
 # Overdue payments are found under this account. Please complete the payment first.
 UNSUPPORTEDOPERATION_UNPAIDORDERALREADYEXISTS = 'UnsupportedOperation.UnpaidOrderAlreadyExists'
 
+# Binding the EIPs specified in `LocalZone` is not supported.
+UNSUPPORTEDOPERATION_UNSUPPORTEDBINDLOCALZONEEIP = 'UnsupportedOperation.UnsupportedBindLocalZoneEIP'
+
 # The specified instance type does not support ENIs.
 UNSUPPORTEDOPERATION_UNSUPPORTEDINSTANCEFAMILY = 'UnsupportedOperation.UnsupportedInstanceFamily'
 
